@@ -185,9 +185,9 @@ class StrUtil:
         :Chinese: 从文本中提取一个词，该词在查找条件before后, 查找条件after前
 
         :param text:    the string
-        :param before:   the texts which is before the finding word, could be a string or a list of string.<br>
-                :Chinese: 查找在 after 之后的词
-        :param after:   the texts which is after the finding word,, could be a sub string or a list of string.<br>
+        :param before:  the before condition, could be a sub string or a list of string.<br>
+                :Chinese: 查找条件before
+        :param after:   the end condition, could be a sub string or a list of string.<br>
                 :Chinese: 查找条件end
         :param begin:    offset to start finding.
                 :Chinese:（可选）开始查找的位置
@@ -228,7 +228,7 @@ class StrUtil:
                 return None
 
     @staticmethod
-    def get_word_list(text, begin, betweens, end=None, start_offset=0):
+    def get_word_list(text, begin, betweens, start_offset=0, end=None):
         """
         get a list of keywords from the text.
 
@@ -251,8 +251,8 @@ class StrUtil:
                          每一个元素单词定义, 一个 2个元素tuple, 第0个元素是before条件，
                          第1个元素是after条件.
 
-        :param end:  (optional) end condition, could be a sub string or a list of string.<br>
         :param start_offset: (optional) offset to start finding
+        :param end:  (optional) end condition, could be a sub string or a list of string.<br>
         :return:  return a list of words
         """
         result = []
